# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.configurations.global_configuration import GlobalConfiguration
from apimatic_core.decorators.lazy_property import LazyProperty
from swaggerpetstoreopenapi30.configuration import Configuration
from swaggerpetstoreopenapi30.controllers.base_controller import BaseController
from swaggerpetstoreopenapi30.configuration import Environment
from swaggerpetstoreopenapi30.http.auth.custom_header_authentication import CustomHeaderAuthentication
from swaggerpetstoreopenapi30.controllers.pet_controller import PetController
from swaggerpetstoreopenapi30.controllers.store_controller\
    import StoreController
from swaggerpetstoreopenapi30.controllers.user_controller import UserController


class Swaggerpetstoreopenapi30Client(object):
    @LazyProperty
    def pet(self):
        return PetController(self.global_configuration)

    @LazyProperty
    def store(self):
        return StoreController(self.global_configuration)

    @LazyProperty
    def user(self):
        return UserController(self.global_configuration)

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=None, retry_methods=None,
                 environment=Environment.PRODUCTION, api_key=None,
                 custom_header_authentication_credentials=None, config=None):
        self.config = config or Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            environment=environment, api_key=api_key,
            custom_header_authentication_credentials=custom_header_authentication_credentials)

        self.global_configuration = GlobalConfiguration(self.config)\
            .global_errors(BaseController.global_errors())\
            .base_uri_executor(self.config.get_base_uri)\
            .user_agent(BaseController.user_agent(), BaseController.user_agent_parameters())

        self.auth_managers = {key: None for key in ['api_key']}
        self.auth_managers['api_key'] = CustomHeaderAuthentication(
            self.config.custom_header_authentication_credentials)
        self.global_configuration = self.global_configuration.auth_managers(self.auth_managers)




# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from swaggerpetstoreopenapi30.api_helper import APIHelper
from swaggerpetstoreopenapi30.configuration import Server
from swaggerpetstoreopenapi30.utilities.file_wrapper import FileWrapper
from swaggerpetstoreopenapi30.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from swaggerpetstoreopenapi30.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from swaggerpetstoreopenapi30.models.pet import Pet
from swaggerpetstoreopenapi30.models.pet_image import PetImage
from swaggerpetstoreopenapi30.exceptions.api_exception import APIException


class PetController(BaseController):

    """A Controller to access Endpoints in the swaggerpetstoreopenapi30 API."""
    def __init__(self, config):
        super(PetController, self).__init__(config)

    def update_pet(self,
                   name,
                   photo_urls,
                   id=None,
                   category=None,
                   tags=None,
                   pet_status=None):
        """Does a PUT request to /pet.

        Update an existing pet by Id

        Args:
            name (str): The request form parameter.
            photo_urls (List[str]): The request form parameter.
            id (int, optional): The request form parameter.
            category (Category, optional): The request form parameter.
            tags (List[Tag], optional): The request form parameter.
            pet_status (PetStatusEnum, optional): pet status in the store

        Returns:
            Pet: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet')
            .http_method(HttpMethodEnum.PUT)
            .form_param(Parameter()
                        .key('name')
                        .value(name))
            .form_param(Parameter()
                        .key('photoUrls')
                        .value(photo_urls))
            .form_param(Parameter()
                        .key('id')
                        .value(id))
            .form_param(Parameter()
                        .key('category')
                        .value(category))
            .form_param(Parameter()
                        .key('tags')
                        .value(tags))
            .form_param(Parameter()
                        .key('petStatus')
                        .value(pet_status))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Pet.from_dictionary)
            .local_error('400', 'Invalid ID supplied', APIException)
            .local_error('404', 'Pet not found', APIException)
            .local_error('405', 'Validation exception', APIException)
        ).execute()

    def add_pet(self,
                name,
                photo_urls,
                id=None,
                category=None,
                tags=None,
                pet_status=None):
        """Does a POST request to /pet.

        Add a new pet to the store

        Args:
            name (str): The request form parameter.
            photo_urls (List[str]): The request form parameter.
            id (int, optional): The request form parameter.
            category (Category, optional): The request form parameter.
            tags (List[Tag], optional): The request form parameter.
            pet_status (PetStatusEnum, optional): pet status in the store

        Returns:
            Pet: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet')
            .http_method(HttpMethodEnum.POST)
            .form_param(Parameter()
                        .key('name')
                        .value(name))
            .form_param(Parameter()
                        .key('photoUrls')
                        .value(photo_urls))
            .form_param(Parameter()
                        .key('id')
                        .value(id))
            .form_param(Parameter()
                        .key('category')
                        .value(category))
            .form_param(Parameter()
                        .key('tags')
                        .value(tags))
            .form_param(Parameter()
                        .key('petStatus')
                        .value(pet_status))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Pet.from_dictionary)
            .local_error('405', 'Invalid input', APIException)
        ).execute()

    def find_pets_by_status(self,
                            status='available'):
        """Does a GET request to /pet/findByStatus.

        Multiple status values can be provided with comma separated strings

        Args:
            status (StatusEnum, optional): Status values that need to be
                considered for filter

        Returns:
            List[Pet]: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/findByStatus')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('status')
                         .value(status))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Pet.from_dictionary)
            .local_error('400', 'Invalid status value', APIException)
        ).execute()

    def find_pets_by_tags(self,
                          tags=None):
        """Does a GET request to /pet/findByTags.

        Multiple tags can be provided with comma separated strings. Use tag1,
        tag2, tag3 for testing.

        Args:
            tags (List[str], optional): Tags to filter by

        Returns:
            List[Pet]: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/findByTags')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('tags')
                         .value(tags))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Pet.from_dictionary)
            .local_error('400', 'Invalid tag value', APIException)
        ).execute()

    def get_pet_by_id(self,
                      pet_id):
        """Does a GET request to /pet/{petId}.

        Returns a single pet

        Args:
            pet_id (int): ID of pet to return

        Returns:
            Pet: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/{petId}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('petId')
                            .value(pet_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('api_key'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Pet.from_dictionary)
            .local_error('400', 'Invalid ID supplied', APIException)
            .local_error('404', 'Pet not found', APIException)
        ).execute()

    def update_pet_with_form(self,
                             pet_id,
                             name=None,
                             status=None):
        """Does a POST request to /pet/{petId}.

        Args:
            pet_id (int): ID of pet that needs to be updated
            name (str, optional): Name of pet that needs to be updated
            status (str, optional): Status of pet that needs to be updated

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/{petId}')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('petId')
                            .value(pet_id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('name')
                         .value(name))
            .query_param(Parameter()
                         .key('status')
                         .value(status))
        ).execute()

    def delete_pet(self,
                   pet_id,
                   api_key=None):
        """Does a DELETE request to /pet/{petId}.

        delete a pet

        Args:
            pet_id (int): Pet id to delete
            api_key (str, optional): The request header parameter.

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/{petId}')
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                            .key('petId')
                            .value(pet_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('api_key')
                          .value(api_key))
        ).execute()

    def upload_file(self,
                    pet_id,
                    additional_metadata=None,
                    body=None):
        """Does a POST request to /pet/{petId}/uploadImage.

        Args:
            pet_id (int): ID of pet to update
            additional_metadata (str, optional): Additional Metadata
            body (typing.BinaryIO, optional): The request form parameter.

        Returns:
            PetImage: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/pet/{petId}/uploadImage')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('petId')
                            .value(pet_id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('additionalMetadata')
                         .value(additional_metadata))
            .multipart_param(Parameter()
                             .key('body')
                             .value(body)
                             .default_content_type('application/octet-stream'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(PetImage.from_dictionary)
        ).execute()



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from swaggerpetstoreopenapi30.api_helper import APIHelper
from swaggerpetstoreopenapi30.models.category import Category
from swaggerpetstoreopenapi30.models.tag import Tag


class Pet(object):

    """Implementation of the 'Pet' model.

    Attributes:
        name (str): The model property of type str.
        photo_urls (List[str]): The model property of type List[str].
        id (int): The model property of type int.
        category (Category): The model property of type Category.
        tags (List[Tag]): The model property of type List[Tag].
        pet_status (PetStatusEnum): pet status in the store

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "photo_urls": 'photoUrls',
        "id": 'id',
        "category": 'category',
        "tags": 'tags',
        "pet_status": 'petStatus'
    }

    _optionals = [
        'id',
        'category',
        'tags',
        'pet_status',
    ]

    def __init__(self,
                 name=None,
                 photo_urls=None,
                 id=APIHelper.SKIP,
                 category=APIHelper.SKIP,
                 tags=APIHelper.SKIP,
                 pet_status=APIHelper.SKIP):
        """Constructor for the Pet class"""

        # Initialize members of the class
        self.name = name 
        self.photo_urls = photo_urls 
        if id is not APIHelper.SKIP:
            self.id = id 
        if category is not APIHelper.SKIP:
            self.category = category 
        if tags is not APIHelper.SKIP:
            self.tags = tags 
        if pet_status is not APIHelper.SKIP:
            self.pet_status = pet_status 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else None
        photo_urls = dictionary.get("photoUrls") if dictionary.get("photoUrls") else None
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        category = Category.from_dictionary(dictionary.get('category')) if 'category' in dictionary.keys() else APIHelper.SKIP
        tags = None
        if dictionary.get('tags') is not None:
            tags = [Tag.from_dictionary(x) for x in dictionary.get('tags')]
        else:
            tags = APIHelper.SKIP
        pet_status = dictionary.get("petStatus") if dictionary.get("petStatus") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   photo_urls,
                   id,
                   category,
                   tags,
                   pet_status)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={self.name!r}, '
                f'photo_urls={self.photo_urls!r}, '
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'category={(self.category if hasattr(self, "category") else None)!r}, '
                f'tags={(self.tags if hasattr(self, "tags") else None)!r}, '
                f'pet_status={(self.pet_status if hasattr(self, "pet_status") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={self.name!s}, '
                f'photo_urls={self.photo_urls!s}, '
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'category={(self.category if hasattr(self, "category") else None)!s}, '
                f'tags={(self.tags if hasattr(self, "tags") else None)!s}, '
                f'pet_status={(self.pet_status if hasattr(self, "pet_status") else None)!s})')



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.authentication.header_auth import HeaderAuth


class CustomHeaderAuthentication(HeaderAuth):

    @property
    def error_message(self):
        """Display error message on occurrence of authentication failure
        in CustomHeaderAuthentication

        """
        return "CustomHeaderAuthentication: api_key is undefined."

    def __init__(self, custom_header_authentication_credentials):
        auth_params = {}
        if custom_header_authentication_credentials is not None \
                and custom_header_authentication_credentials.api_key is not None:
            auth_params["api_key"] = custom_header_authentication_credentials.api_key
        super().__init__(auth_params=auth_params)


class CustomHeaderAuthenticationCredentials:

    @property
    def api_key(self):
        return self._api_key

    def __init__(self, api_key):
        if api_key is None:
            raise ValueError('api_key cannot be None')
        self._api_key = api_key

    def clone_with(self, api_key=None):
        return CustomHeaderAuthenticationCredentials(api_key or self.api_key)



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from swaggerpetstoreopenapi30.api_helper import APIHelper


class Address(object):

    """Implementation of the 'Address' model.

    Attributes:
        street (str): The model property of type str.
        city (str): The model property of type str.
        state (str): The model property of type str.
        zip (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "street": 'street',
        "city": 'city',
        "state": 'state',
        "zip": 'zip'
    }

    _optionals = [
        'street',
        'city',
        'state',
        'zip',
    ]

    def __init__(self,
                 street=APIHelper.SKIP,
                 city=APIHelper.SKIP,
                 state=APIHelper.SKIP,
                 zip=APIHelper.SKIP):
        """Constructor for the Address class"""

        # Initialize members of the class
        if street is not APIHelper.SKIP:
            self.street = street 
        if city is not APIHelper.SKIP:
            self.city = city 
        if state is not APIHelper.SKIP:
            self.state = state 
        if zip is not APIHelper.SKIP:
            self.zip = zip 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        street = dictionary.get("street") if dictionary.get("street") else APIHelper.SKIP
        city = dictionary.get("city") if dictionary.get("city") else APIHelper.SKIP
        state = dictionary.get("state") if dictionary.get("state") else APIHelper.SKIP
        zip = dictionary.get("zip") if dictionary.get("zip") else APIHelper.SKIP
        # Return an object of this model
        return cls(street,
                   city,
                   state,
                   zip)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'street={(self.street if hasattr(self, "street") else None)!r}, '
                f'city={(self.city if hasattr(self, "city") else None)!r}, '
                f'state={(self.state if hasattr(self, "state") else None)!r}, '
                f'zip={(self.zip if hasattr(self, "zip") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'street={(self.street if hasattr(self, "street") else None)!s}, '
                f'city={(self.city if hasattr(self, "city") else None)!s}, '
                f'state={(self.state if hasattr(self, "state") else None)!s}, '
                f'zip={(self.zip if hasattr(self, "zip") else None)!s})')



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PetStatusEnum(object):

    """Implementation of the 'PetStatus' enum.

    pet status in the store

    Attributes:
        AVAILABLE: The enum member of type str.
        PENDING: The enum member of type str.
        SOLD: The enum member of type str.

    """
    AVAILABLE = 'available'

    PENDING = 'pending'

    SOLD = 'sold'




# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from swaggerpetstoreopenapi30.api_helper import APIHelper


class Order(object):

    """Implementation of the 'Order' model.

    Attributes:
        id (int): The model property of type int.
        pet_id (int): The model property of type int.
        quantity (int): The model property of type int.
        ship_date (datetime): The model property of type datetime.
        order_status (OrderStatusEnum): Order Status
        complete (bool): The model property of type bool.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "pet_id": 'petId',
        "quantity": 'quantity',
        "ship_date": 'shipDate',
        "order_status": 'orderStatus',
        "complete": 'complete'
    }

    _optionals = [
        'id',
        'pet_id',
        'quantity',
        'ship_date',
        'order_status',
        'complete',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 pet_id=APIHelper.SKIP,
                 quantity=APIHelper.SKIP,
                 ship_date=APIHelper.SKIP,
                 order_status='approved',
                 complete=APIHelper.SKIP):
        """Constructor for the Order class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if pet_id is not APIHelper.SKIP:
            self.pet_id = pet_id 
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity 
        if ship_date is not APIHelper.SKIP:
            self.ship_date = APIHelper.apply_datetime_converter(ship_date, APIHelper.RFC3339DateTime) if ship_date else None 
        self.order_status = order_status 
        if complete is not APIHelper.SKIP:
            self.complete = complete 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        pet_id = dictionary.get("petId") if dictionary.get("petId") else APIHelper.SKIP
        quantity = dictionary.get("quantity") if dictionary.get("quantity") else APIHelper.SKIP
        ship_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("shipDate")).datetime if dictionary.get("shipDate") else APIHelper.SKIP
        order_status = dictionary.get("orderStatus") if dictionary.get("orderStatus") else 'approved'
        complete = dictionary.get("complete") if "complete" in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   pet_id,
                   quantity,
                   ship_date,
                   order_status,
                   complete)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'pet_id={(self.pet_id if hasattr(self, "pet_id") else None)!r}, '
                f'quantity={(self.quantity if hasattr(self, "quantity") else None)!r}, '
                f'ship_date={(self.ship_date if hasattr(self, "ship_date") else None)!r}, '
                f'order_status={(self.order_status if hasattr(self, "order_status") else None)!r}, '
                f'complete={(self.complete if hasattr(self, "complete") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'pet_id={(self.pet_id if hasattr(self, "pet_id") else None)!s}, '
                f'quantity={(self.quantity if hasattr(self, "quantity") else None)!s}, '
                f'ship_date={(self.ship_date if hasattr(self, "ship_date") else None)!s}, '
                f'order_status={(self.order_status if hasattr(self, "order_status") else None)!s}, '
                f'complete={(self.complete if hasattr(self, "complete") else None)!s})')



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from swaggerpetstoreopenapi30.api_helper import APIHelper
from swaggerpetstoreopenapi30.configuration import Server
from swaggerpetstoreopenapi30.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from swaggerpetstoreopenapi30.http.http_method_enum import HttpMethodEnum
from swaggerpetstoreopenapi30.models.user import User
from swaggerpetstoreopenapi30.exceptions.api_exception import APIException


class UserController(BaseController):

    """A Controller to access Endpoints in the swaggerpetstoreopenapi30 API."""
    def __init__(self, config):
        super(UserController, self).__init__(config)

    def create_user(self,
                    id=None,
                    username=None,
                    first_name=None,
                    last_name=None,
                    email=None,
                    password=None,
                    phone=None,
                    user_status=None):
        """Does a POST request to /user.

        This can only be done by the logged in user.

        Args:
            id (int, optional): The request form parameter.
            username (str, optional): The request form parameter.
            first_name (str, optional): The request form parameter.
            last_name (str, optional): The request form parameter.
            email (str, optional): The request form parameter.
            password (str, optional): The request form parameter.
            phone (str, optional): The request form parameter.
            user_status (int, optional): User Status

        Returns:
            User: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user')
            .http_method(HttpMethodEnum.POST)
            .form_param(Parameter()
                        .key('id')
                        .value(id))
            .form_param(Parameter()
                        .key('username')
                        .value(username))
            .form_param(Parameter()
                        .key('firstName')
                        .value(first_name))
            .form_param(Parameter()
                        .key('lastName')
                        .value(last_name))
            .form_param(Parameter()
                        .key('email')
                        .value(email))
            .form_param(Parameter()
                        .key('password')
                        .value(password))
            .form_param(Parameter()
                        .key('phone')
                        .value(phone))
            .form_param(Parameter()
                        .key('userStatus')
                        .value(user_status))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(User.from_dictionary)
        ).execute()

    def create_users_with_list_input(self,
                                     body=None):
        """Does a POST request to /user/createWithList.

        Creates list of users with given input array

        Args:
            body (List[User], optional): The request body parameter.

        Returns:
            User: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/createWithList')
            .http_method(HttpMethodEnum.POST)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(body))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(User.from_dictionary)
            .local_error('default', 'successful operation', APIException)
        ).execute()

    def login_user(self,
                   username=None,
                   password=None):
        """Does a GET request to /user/login.

        Args:
            username (str, optional): The user name for login
            password (str, optional): The password for login in clear text

        Returns:
            str: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/login')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('username')
                         .value(username))
            .query_param(Parameter()
                         .key('password')
                         .value(password))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .local_error('400', 'Invalid username/password supplied', APIException)
        ).execute()

    def logout_user(self):
        """Does a GET request to /user/logout.

        Returns:
            void: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/logout')
            .http_method(HttpMethodEnum.GET)
        ).execute()

    def get_user_by_name(self,
                         name):
        """Does a GET request to /user/{name}.

        Args:
            name (str): The name that needs to be fetched. Use user1 for
                testing.

        Returns:
            User: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/{name}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('name')
                            .value(name)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(User.from_dictionary)
            .local_error('400', 'Invalid username supplied', APIException)
            .local_error('404', 'User not found', APIException)
        ).execute()

    def update_user(self,
                    name,
                    id=None,
                    username=None,
                    first_name=None,
                    last_name=None,
                    email=None,
                    password=None,
                    phone=None,
                    user_status=None):
        """Does a PUT request to /user/{name}.

        This can only be done by the logged in user.

        Args:
            name (str): name that need to be deleted
            id (int, optional): The request form parameter.
            username (str, optional): The request form parameter.
            first_name (str, optional): The request form parameter.
            last_name (str, optional): The request form parameter.
            email (str, optional): The request form parameter.
            password (str, optional): The request form parameter.
            phone (str, optional): The request form parameter.
            user_status (int, optional): User Status

        Returns:
            void: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/{name}')
            .http_method(HttpMethodEnum.PUT)
            .template_param(Parameter()
                            .key('name')
                            .value(name)
                            .should_encode(True))
            .form_param(Parameter()
                        .key('id')
                        .value(id))
            .form_param(Parameter()
                        .key('username')
                        .value(username))
            .form_param(Parameter()
                        .key('firstName')
                        .value(first_name))
            .form_param(Parameter()
                        .key('lastName')
                        .value(last_name))
            .form_param(Parameter()
                        .key('email')
                        .value(email))
            .form_param(Parameter()
                        .key('password')
                        .value(password))
            .form_param(Parameter()
                        .key('phone')
                        .value(phone))
            .form_param(Parameter()
                        .key('userStatus')
                        .value(user_status))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
        ).execute()

    def delete_user(self,
                    name):
        """Does a DELETE request to /user/{name}.

        This can only be done by the logged in user.

        Args:
            name (str): The name that needs to be deleted

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/user/{name}')
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                            .key('name')
                            .value(name)
                            .should_encode(True))
        ).execute()



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from swaggerpetstoreopenapi30.api_helper import APIHelper


class PetImage(object):

    """Implementation of the 'PetImage' model.

    Attributes:
        code (int): The model property of type int.
        mtype (str): The model property of type str.
        message (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code": 'code',
        "mtype": 'type',
        "message": 'message'
    }

    _optionals = [
        'code',
        'mtype',
        'message',
    ]

    def __init__(self,
                 code=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 message=APIHelper.SKIP):
        """Constructor for the PetImage class"""

        # Initialize members of the class
        if code is not APIHelper.SKIP:
            self.code = code 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if message is not APIHelper.SKIP:
            self.message = message 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get("code") if dictionary.get("code") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        message = dictionary.get("message") if dictionary.get("message") else APIHelper.SKIP
        # Return an object of this model
        return cls(code,
                   mtype,
                   message)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'code={(self.code if hasattr(self, "code") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r}, '
                f'message={(self.message if hasattr(self, "message") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'code={(self.code if hasattr(self, "code") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s}, '
                f'message={(self.message if hasattr(self, "message") else None)!s})')



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from swaggerpetstoreopenapi30.api_helper import APIHelper
from swaggerpetstoreopenapi30.configuration import Server
from swaggerpetstoreopenapi30.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from swaggerpetstoreopenapi30.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from swaggerpetstoreopenapi30.models.order import Order
from swaggerpetstoreopenapi30.exceptions.api_exception import APIException


class StoreController(BaseController):

    """A Controller to access Endpoints in the swaggerpetstoreopenapi30 API."""
    def __init__(self, config):
        super(StoreController, self).__init__(config)

    def get_inventory(self):
        """Does a GET request to /store/inventory.

        Returns a map of status codes to quantities

        Returns:
            Dict[str, int]: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/store/inventory')
            .http_method(HttpMethodEnum.GET)
            .auth(Single('api_key'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
        ).execute()

    def place_order(self,
                    id=None,
                    pet_id=None,
                    quantity=None,
                    ship_date=None,
                    order_status='approved',
                    complete=None):
        """Does a POST request to /store/order.

        Place a new order in the store

        Args:
            id (int, optional): The request form parameter.
            pet_id (int, optional): The request form parameter.
            quantity (int, optional): The request form parameter.
            ship_date (datetime, optional): The request form parameter.
            order_status (OrderStatusEnum, optional): Order Status
            complete (bool, optional): The request form parameter.

        Returns:
            Order: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/store/order')
            .http_method(HttpMethodEnum.POST)
            .form_param(Parameter()
                        .key('id')
                        .value(id))
            .form_param(Parameter()
                        .key('petId')
                        .value(pet_id))
            .form_param(Parameter()
                        .key('quantity')
                        .value(quantity))
            .form_param(Parameter()
                        .key('shipDate')
                        .value(APIHelper.when_defined(APIHelper.RFC3339DateTime, ship_date)))
            .form_param(Parameter()
                        .key('orderStatus')
                        .value(order_status))
            .form_param(Parameter()
                        .key('complete')
                        .value(complete))
            .header_param(Parameter()
                          .key('content-type')
                          .value('application/x-www-form-urlencoded'))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('405', 'Invalid input', APIException)
        ).execute()

    def get_order_by_id(self,
                        order_id):
        """Does a GET request to /store/order/{orderId}.

        For valid response try integer IDs with value <= 5 or > 10. Other
        values will generate exceptions.

        Args:
            order_id (int): ID of order that needs to be fetched

        Returns:
            Order: Response from the API. successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/store/order/{orderId}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('orderId')
                            .value(order_id)
                            .should_encode(True))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('400', 'Invalid ID supplied', APIException)
            .local_error('404', 'Order not found', APIException)
        ).execute()

    def delete_order(self,
                     order_id):
        """Does a DELETE request to /store/order/{orderId}.

        For valid response try integer IDs with value < 1000. Anything above
        1000 or nonintegers will generate API errors

        Args:
            order_id (int): ID of the order that needs to be deleted

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/store/order/{orderId}')
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                            .key('orderId')
                            .value(order_id)
                            .should_encode(True))
        ).execute()



# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderStatusEnum(object):

    """Implementation of the 'OrderStatus' enum.

    Order Status

    Attributes:
        PLACED: The enum member of type str.
        APPROVED: The enum member of type str.
        DELIVERED: The enum member of type str.

    """
    PLACED = 'placed'

    APPROVED = 'approved'

    DELIVERED = 'delivered'

